from setuptools import find_packages, setup

setup(
    name='sswg',
    version='2.3.0',
    py_modules=['sswg'],
    url='https://github.com/pokepetter/sswg',
    author='Petter Amland',
    author_email='pokepetter@gmail.com',
    license='MIT',
    keywords='website generator',
    )
